@@ -10,8 +10,7 @@ from zeep.cache import SqliteCache
 from zeep.exceptions import Fault
 from zeep.wsse.username import UsernameToken
 
-from .utils import ONVIFOperationException
-from .utils.zeep import flatten_xsd_any_fields
+from .utils import ONVIFOperationException, ZeepPatcher
 
 
 class CacheMode(Enum):
@@ -117,7 +116,7 @@ class ONVIFOperator:
             raise ValueError("Bindings must be set according to the WSDL service")
 
         self.service = self.client.create_service(binding, self.address)
-        logging.debug(f"ONVIFCore initialized {binding} at {self.address}")
+        # logging.debug(f"ONVIFOperator initialized {binding} at {self.address}")
 
     def call(self, method: str, *args, **kwargs):
         try:
@@ -129,7 +128,7 @@ class ONVIFOperator:
             result = func(*args, **kwargs)
             # Post-process to flatten xsd:any fields if enabled (> v0.0.4 patch)
             if self.apply_flatten:
-                return flatten_xsd_any_fields(result)
+                return ZeepPatcher.flatten_xsd_any_fields(result)
             return result
         except Fault as e:
             # logging.error(f"SOAP Fault in {method}: {e}")
